@@ -5,18 +5,15 @@ import re
 import warnings
 from contextlib import contextmanager
 from collections import defaultdict
-import types as py_types
 from llvmlite import ir
 import llvmlite.binding as llvm
 from .targetinfo import TargetInfo
 from .errors import UnsupportedError
-from .utils import get_version
-from . import libfuncs, structure_type
-from rbc import externals
-from rbc.omnisci_backend import mathimpl
+from . import libfuncs
+from rbc.externals import stdio
 from numba.core import codegen, cpu, compiler_lock, \
     registry, typing, compiler, sigutils, cgutils, \
-    extending
+    extending, imputils
 from numba.core import errors as nb_errors
 
 
@@ -104,16 +101,40 @@ class JITRemoteCodegen(codegen.JITCPUCodegen):
 
         # See https://github.com/xnd-project/rbc/issues/45
         remove_features = {
+            (12, 12): [], (11, 11): [], (10, 10): [], (9, 9): [], (8, 8): [],
             (11, 8): ['tsxldtrk', 'amx-tile', 'amx-bf16', 'serialize', 'amx-int8',
                       'avx512vp2intersect', 'tsxldtrk', 'amx-tile', 'amx-bf16',
                       'serialize', 'amx-int8', 'avx512vp2intersect', 'tsxldtrk',
                       'amx-tile', 'amx-bf16', 'serialize', 'amx-int8',
                       'avx512vp2intersect', 'cx8', 'enqcmd', 'avx512bf16'],
             (11, 10): ['tsxldtrk', 'amx-tile', 'amx-bf16', 'serialize', 'amx-int8'],
+            (9, 11): ['sse2', 'cx16', 'sahf', 'tbm', 'avx512ifma', 'sha',
+                      'gfni', 'fma4', 'vpclmulqdq', 'prfchw', 'bmi2', 'cldemote',
+                      'fsgsbase', 'ptwrite', 'xsavec', 'popcnt', 'mpx',
+                      'avx512bitalg', 'movdiri', 'xsaves', 'avx512er',
+                      'avx512vnni', 'avx512vpopcntdq', 'pconfig', 'clwb',
+                      'avx512f', 'clzero', 'pku', 'mmx', 'lwp', 'rdpid', 'xop',
+                      'rdseed', 'waitpkg', 'movdir64b', 'sse4a', 'avx512bw',
+                      'clflushopt', 'xsave', 'avx512vbmi2', '64bit', 'avx512vl',
+                      'invpcid', 'avx512cd', 'avx', 'vaes', 'cx8', 'fma', 'rtm',
+                      'bmi', 'enqcmd', 'rdrnd', 'mwaitx', 'sse4.1', 'sse4.2', 'avx2',
+                      'fxsr', 'wbnoinvd', 'sse', 'lzcnt', 'pclmul', 'prefetchwt1',
+                      'f16c', 'ssse3', 'sgx', 'shstk', 'cmov', 'avx512vbmi',
+                      'avx512bf16', 'movbe', 'xsaveopt', 'avx512dq', 'adx',
+                      'avx512pf', 'sse3'],
             (9, 8): ['cx8', 'enqcmd', 'avx512bf16'],
-        }.get((server_llvm_version[0], client_llvm_version[0]), [])
-        for f in remove_features:
-            features = features.replace('+' + f, '').replace('-' + f, '')
+        }.get((server_llvm_version[0], client_llvm_version[0]), None)
+        if remove_features is None:
+            warnings.warn(
+                f'{type(self).__name__}._get_host_cpu_features: `remove_features` dictionary'
+                ' requires an update: detected different LLVM versions in server '
+                f'{server_llvm_version} and client {client_llvm_version}.'
+                f' CPU features: {features}.')
+        else:
+            features += ','
+            for f in remove_features:
+                features = features.replace('+' + f + ',', '').replace('-' + f + ',', '')
+            features.rstrip(',')
         return features
 
     def _customize_tm_options(self, options):
@@ -132,16 +153,7 @@ class JITRemoteCodegen(codegen.JITCPUCodegen):
 
 class JITRemoteTypingContext(typing.Context):
     def load_additional_registries(self):
-        for module in externals.__dict__.values():
-            if not isinstance(module, py_types.ModuleType):
-                continue
-
-            typing_registry = getattr(module, 'typing_registry', None)
-            if typing_registry:
-                self.install_registry(typing_registry)
-
-        self.install_registry(mathimpl.typing_registry)
-        self.install_registry(structure_type.typing_registry)
+        self.install_registry(typing.templates.builtin_registry)
         super().load_additional_registries()
 
 
@@ -155,19 +167,7 @@ class JITRemoteTargetContext(cpu.CPUContext):
         self._internal_codegen = JITRemoteCodegen("numba.exec")
 
     def load_additional_registries(self):
-        for module in externals.__dict__.values():
-            if not isinstance(module, py_types.ModuleType):
-                continue
-
-            if 'rbc.externals' not in module.__name__:
-                continue
-
-            lowering_registry = getattr(module, 'lowering_registry', None)
-            if lowering_registry:
-                self.install_registry(lowering_registry)
-
-        self.install_registry(mathimpl.lowering_registry)
-        self.install_registry(structure_type.lowering_registry)
+        self.install_registry(imputils.builtin_registry)
         super().load_additional_registries()
 
     def get_executable(self, library, fndesc, env):
@@ -243,9 +243,10 @@ def make_wrapper(fname, atypes, rtype, cres, target: TargetInfo, verbose=False):
                 cgutils.printf(builder,
                                f"rbc: {fname} failed with status code %i\n",
                                status.code)
-                externals.stdio.cg_fflush(builder)
+                stdio._cg_fflush(builder)
             builder.ret_void()
-        builder.store(builder.load(out), wrapfn.args[0])
+        # does a "deepcopy"
+        rtype.deepcopy(context, builder, out, wrapfn.args[0])
         builder.ret_void()
     else:
         wrapty = ir.FunctionType(ll_return_type, ll_argtypes)
@@ -260,7 +261,7 @@ def make_wrapper(fname, atypes, rtype, cres, target: TargetInfo, verbose=False):
                 cgutils.printf(builder,
                                f"rbc: {fname} failed with status code %i\n",
                                status.code)
-                externals.stdio.cg_fflush(builder)
+                stdio._cg_fflush(builder)
         builder.ret(out)
 
     cres.library.add_ir_module(module)
@@ -277,14 +278,10 @@ def compile_instance(func, sig,
     succesful.
     """
     flags = compiler.Flags()
-    if get_version('numba') >= (0, 54):
-        flags.no_compile = True
-        flags.no_cpython_wrapper = True
-        flags.no_cfunc_wrapper = True
-    else:
-        flags.set('no_compile')
-        flags.set('no_cpython_wrapper')
-        flags.set('no_cfunc_wrapper')
+    flags.no_compile = True
+    flags.no_cpython_wrapper = True
+    flags.no_cfunc_wrapper = True
+    flags.nrt = True
 
     fname = func.__name__ + sig.mangling()
     args, return_type = sigutils.normalize_signature(
@@ -299,13 +296,9 @@ def compile_instance(func, sig,
                                       library=main_library,
                                       locals={},
                                       pipeline_class=pipeline_class)
-    except UnsupportedError as msg:
-        for m in re.finditer(r'[|]UnsupportedError[|](.*?)\n', str(msg), re.S):
-            warnings.warn(f'Skipping {fname}: {m.group(0)[18:]}')
-        return
-    except nb_errors.TypingError as msg:
-        for m in re.finditer(r'[|]UnsupportedError[|](.*?)\n', str(msg), re.S):
-            warnings.warn(f'Skipping {fname}: {m.group(0)[18:]}')
+    except (UnsupportedError, nb_errors.TypingError, nb_errors.LoweringError) as msg:
+        for m in re.finditer(r'UnsupportedError(.*?)\n', str(msg), re.S):
+            warnings.warn(f'Skipping {fname}:{m.group(0)[18:]}')
             break
         else:
             raise
@@ -346,13 +339,13 @@ def compile_instance(func, sig,
     return fname
 
 
-def add_byval_metadata(main_library):
+def add_metadata_flag(main_library, **kwargs):
     module = ir.Module()
-    flag_name = "pass_column_arguments_by_value"
     mflags = module.add_named_metadata('llvm.module.flags')
     override_flag = int32_t(4)
-    flag = module.add_metadata([override_flag, flag_name, int1_t(0)])
-    mflags.add(flag)
+    for flag_name, flag_value in kwargs.items():
+        flag = module.add_metadata([override_flag, flag_name, int1_t(flag_value)])
+        mflags.add(flag)
     main_library.add_ir_module(module)
 
 
@@ -411,7 +404,9 @@ def compile_to_LLVM(functions_and_signatures,
                     succesful_fids.append(fid)
                     function_names.append(fname)
 
-        add_byval_metadata(main_library)
+        add_metadata_flag(main_library,
+                          pass_column_arguments_by_value=0,
+                          manage_memory_buffer=1)
         main_library._optimize_final_module()
 
         # Remove unused defined functions and declarations
