@@ -7,7 +7,7 @@ https://data-apis.org/array- api/latest/API_specification/elementwise_functions.
 from rbc.stdlib import Expose, BinaryUfuncExpose, UnaryUfuncExpose, API, determine_input_type
 import numpy as np
 from rbc import typesystem
-from rbc.omnisci_backend import ArrayPointer, Array
+from rbc.heavydb import ArrayPointer, Array
 from numba.core import types
 
 
@@ -27,10 +27,11 @@ __all__ = [
     'rad2deg', 'logical_not', 'isfinite', 'isinf', 'isnan', 'fabs',
     'floor', 'ceil', 'trunc', 'signbit', 'copysign', 'spacing',
     'heaviside', 'bitwise_left_shift', 'bitwise_right_shift',
-    'round',
+    'round', 'isnat',
     # numpy specifics
     'power', 'arctan2', 'left_shift', 'right_shift', 'absolute',
-    'invert', 'arcsin', 'arctan', 'arccos', 'arcsinh', 'arccosh', 'arctanh'
+    'invert', 'arcsin', 'arctan', 'arccos', 'arcsinh', 'arccosh', 'arctanh',
+    'float_power', 'divmod', 'cbrt',
 ]
 
 
@@ -41,7 +42,7 @@ unary_expose = UnaryUfuncExpose(globals(), 'elementwise_functions')
 
 # math functions
 @binary_expose.implements(np.add)
-def _omnisci_add(x1, x2):
+def _impl_add(x1, x2):
     """
     Calculates the sum for each element x1_i of the input array x1 with the respective element
     x2_i of the input array x2.
@@ -50,7 +51,7 @@ def _omnisci_add(x1, x2):
 
 
 @binary_expose.implements(np.subtract)
-def _omnisci_ufunc_subtract(x1, x2):
+def _impl_ufunc_subtract(x1, x2):
     """
     Calculates the difference for each element x1_i of the input array x1 with the respective
     element x2_i of the input array x2.
@@ -59,7 +60,7 @@ def _omnisci_ufunc_subtract(x1, x2):
 
 
 @binary_expose.implements(np.multiply)
-def _omnisci_ufunc_multiply(x1, x2):
+def _impl_ufunc_multiply(x1, x2):
     """
     Calculates the product for each element x1_i of the input array x1 with the respective element
     x2_i of the input array x2.
@@ -68,7 +69,7 @@ def _omnisci_ufunc_multiply(x1, x2):
 
 
 @binary_expose.implements(np.divide, ufunc_name='divide')
-def _omnisci_ufunc_divide(x1, x2):
+def _impl_ufunc_divide(x1, x2):
     """
     Calculates the division for each element x1_i of the input array x1 with the respective
     element x2_i of the input array x2.
@@ -77,7 +78,7 @@ def _omnisci_ufunc_divide(x1, x2):
 
 
 @binary_expose.implements(np.logaddexp)
-def _omnisci_ufunc_logaddexp(x1, x2):
+def _impl_ufunc_logaddexp(x1, x2):
     """
     Calculates the logarithm of the sum of exponentiations ``log(exp(x1) + exp(x2))`` for each
     element x1_i of the input array x1 with the respective element x2_i of the input array x2.
@@ -86,22 +87,22 @@ def _omnisci_ufunc_logaddexp(x1, x2):
 
 
 @binary_expose.implements(np.copysign, api=API.NUMPY_API)
-def _omnisci_ufunc_copysign(x1, x2):
+def _impl_ufunc_copysign(x1, x2):
     pass
 
 
 @binary_expose.implements(np.logaddexp2, api=API.NUMPY_API)
-def _omnisci_ufunc_logaddexp2(x1, x2):
+def _impl_ufunc_logaddexp2(x1, x2):
     pass
 
 
-@binary_expose.implements(np.true_divide, api=API.NUMPY_API)
-def _omnisci_ufunc_true_divide(x1, x2):
+@binary_expose.implements(np.true_divide, ufunc_name="true_divide", api=API.NUMPY_API)
+def _impl_ufunc_true_divide(x1, x2):
     pass
 
 
 @binary_expose.implements(np.floor_divide)
-def _omnisci_ufunc_floor_divide(x1, x2):
+def _impl_ufunc_floor_divide(x1, x2):
     """
     Rounds the result of dividing each element x1_i of the input array x1 by the respective
     element x2_i of the input array x2 to the greatest (i.e., closest to +infinity) integer-value
@@ -111,12 +112,12 @@ def _omnisci_ufunc_floor_divide(x1, x2):
 
 
 @binary_expose.implements(np.power, ufunc_name='power', api=API.NUMPY_API)
-def _omnisci_ufunc_power(x1, x2):
+def _impl_ufunc_power(x1, x2):
     pass
 
 
 @binary_expose.implements(np.power, ufunc_name='pow')
-def _omnisci_ufunc_pow(x1, x2):
+def _impl_ufunc_pow(x1, x2):
     """
     Calculates an implementation-dependent approximation of exponentiation by raising each element
     x1_i (the base) of the input array x1 to the power of x2_i (the exponent), where x2_i is the
@@ -126,12 +127,12 @@ def _omnisci_ufunc_pow(x1, x2):
 
 
 @binary_expose.not_implemented('float_power')  # not supported by Numba
-def _omnisci_ufunc_float_power(x1, x2):
+def _impl_ufunc_float_power(x1, x2):
     pass
 
 
 @binary_expose.implements(np.remainder)
-def _omnisci_ufunc_remainder(x1, x2):
+def _impl_ufunc_remainder(x1, x2):
     """
     Returns the remainder of division for each element x1_i of the input array x1 and the
     respective element x2_i of the input array x2.
@@ -140,33 +141,33 @@ def _omnisci_ufunc_remainder(x1, x2):
 
 
 @binary_expose.implements(np.mod, ufunc_name='mod', api=API.NUMPY_API)
-def _omnisci_ufunc_mod(x1, x2):
+def _impl_ufunc_mod(x1, x2):
     pass
 
 
 @binary_expose.implements(np.fmod, api=API.NUMPY_API)
-def _omnisci_ufunc_fmod(x1, x2):
+def _impl_ufunc_fmod(x1, x2):
     pass
 
 
 @binary_expose.not_implemented('divmod')  # not supported by Numba
-def _omnisci_ufunc_divmod(x1, x2):
+def _impl_ufunc_divmod(x1, x2):
     pass
 
 
 @binary_expose.implements(np.gcd, api=API.NUMPY_API)
-def _omnisci_ufunc_gcd(x1, x2):
+def _impl_ufunc_gcd(x1, x2):
     pass
 
 
 @binary_expose.implements(np.lcm, api=API.NUMPY_API)
-def _omnisci_ufunc_lcm(x1, x2):
+def _impl_ufunc_lcm(x1, x2):
     pass
 
 
 # Bit-twiddling functions
 @binary_expose.implements(np.bitwise_and)
-def _omnisci_ufunc_bitwise_and(x1, x2):
+def _impl_ufunc_bitwise_and(x1, x2):
     """
     Computes the bitwise AND of the underlying binary representation of each element x1_iof the
     input array x1 with the respective element x2_i of the input array x2.
@@ -175,7 +176,7 @@ def _omnisci_ufunc_bitwise_and(x1, x2):
 
 
 @binary_expose.implements(np.bitwise_or)
-def _omnisci_ufunc_bitwise_or(x1, x2):
+def _impl_ufunc_bitwise_or(x1, x2):
     """
     Computes the bitwise OR of the underlying binary representation of each element x1_i of the
     input array x1 with the respective element x2_i of the input array x2.
@@ -184,7 +185,7 @@ def _omnisci_ufunc_bitwise_or(x1, x2):
 
 
 @binary_expose.implements(np.bitwise_xor)
-def _omnisci_ufunc_bitwise_xor(x1, x2):
+def _impl_ufunc_bitwise_xor(x1, x2):
     """
     Computes the bitwise XOR of the underlying binary representation of each element x1_i of the
     input array x1 with the respective element x2_i of the input array x2.
@@ -193,7 +194,7 @@ def _omnisci_ufunc_bitwise_xor(x1, x2):
 
 
 @binary_expose.implements(np.bitwise_not, ufunc_name='bitwise_not')
-def _omnisci_ufunc_bitwise_not(x1, x2):
+def _impl_ufunc_bitwise_not(x1, x2):
     """
     Computes the bitwise NOR of the underlying binary representation of each element x1_i of the
     input array x1 with the respective element x2_i of the input array x2.
@@ -202,12 +203,12 @@ def _omnisci_ufunc_bitwise_not(x1, x2):
 
 
 @binary_expose.implements(np.left_shift, api=API.NUMPY_API)
-def _omnisci_ufunc_left_shift(x1, x2):
+def _impl_ufunc_left_shift(x1, x2):
     pass
 
 
 @binary_expose.implements(np.left_shift, ufunc_name='bitwise_left_shift')
-def _omnisci_ufunc_bitwise_left_shift(x1, x2):
+def _impl_ufunc_bitwise_left_shift(x1, x2):
     """
     Shifts the bits of each element x1_i of the input array x1 to the left by appending x2_i
     (i.e., the respective element in the input array x2) zeros to the right of x1_i.
@@ -216,12 +217,12 @@ def _omnisci_ufunc_bitwise_left_shift(x1, x2):
 
 
 @binary_expose.implements(np.right_shift, api=API.NUMPY_API)
-def _omnisci_ufunc_right_shift(x1, x2):
+def _impl_ufunc_right_shift(x1, x2):
     pass
 
 
 @binary_expose.implements(np.right_shift, ufunc_name='bitwise_right_shift')
-def _omnisci_ufunc_bitwise_right_shift(x1, x2):
+def _impl_ufunc_bitwise_right_shift(x1, x2):
     """
     Shifts the bits of each element x1_i of the input array x1 to the right by appending x2_i
     (i.e., the respective element in the input array x2) zeros to the right of x1_i.
@@ -231,12 +232,12 @@ def _omnisci_ufunc_bitwise_right_shift(x1, x2):
 
 # trigonometric functions
 @binary_expose.implements(np.arctan2, api=API.NUMPY_API)
-def _omnisci_ufunc_arctan2(x1, x2):
+def _impl_ufunc_arctan2(x1, x2):
     pass
 
 
 @binary_expose.implements(np.arctan2, ufunc_name='atan2')
-def _omnisci_ufunc_atan2(x1, x2):
+def _impl_ufunc_atan2(x1, x2):
     """
     Calculates an implementation-dependent approximation of the inverse tangent of the quotient
     x1/x2, having domain [-infinity, +infinity] x ``[-infinity, +infinity]`` (where the x notation
@@ -247,13 +248,13 @@ def _omnisci_ufunc_atan2(x1, x2):
 
 
 @binary_expose.implements(np.hypot, api=API.NUMPY_API)
-def _omnisci_ufunc_hypot(x1, x2):
+def _impl_ufunc_hypot(x1, x2):
     pass
 
 
 # Comparison functions
 @binary_expose.implements(np.greater, dtype=typesystem.boolean8)
-def _omnisci_ufunc_greater(x1, x2):
+def _impl_ufunc_greater(x1, x2):
     """
     Computes the truth value of x1_i > x2_i for each element x1_i of the input array x1 with the
     respective element x2_i of the input array x2.
@@ -262,7 +263,7 @@ def _omnisci_ufunc_greater(x1, x2):
 
 
 @binary_expose.implements(np.greater_equal, dtype=typesystem.boolean8)
-def _omnisci_ufunc_greater_equal(x1, x2):
+def _impl_ufunc_greater_equal(x1, x2):
     """
     Computes the truth value of x1_i >= x2_i for each element x1_i of the input array x1 with the
     respective element x2_i of the input array x2.
@@ -271,7 +272,7 @@ def _omnisci_ufunc_greater_equal(x1, x2):
 
 
 @binary_expose.implements(np.less, dtype=typesystem.boolean8)
-def _omnisci_ufunc_less(x1, x2):
+def _impl_ufunc_less(x1, x2):
     """
     Computes the truth value of x1_i < x2_i for each element x1_i of the input array x1 with the
     respective element x2_i of the input array x2.
@@ -280,7 +281,7 @@ def _omnisci_ufunc_less(x1, x2):
 
 
 @binary_expose.implements(np.less_equal, dtype=typesystem.boolean8)
-def _omnisci_ufunc_less_equal(x1, x2):
+def _impl_ufunc_less_equal(x1, x2):
     """
     Computes the truth value of x1_i <= x2_i for each element x1_i of the input array x1 with the
     respective element x2_i of the input array x2.
@@ -289,7 +290,7 @@ def _omnisci_ufunc_less_equal(x1, x2):
 
 
 @binary_expose.implements(np.not_equal, dtype=typesystem.boolean8)
-def _omnisci_ufunc_not_equal(x1, x2):
+def _impl_ufunc_not_equal(x1, x2):
     """
     Computes the truth value of x1_i != x2_i for each element x1_i of the input array x1 with the
     respective element x2_i of the input array x2.
@@ -298,7 +299,7 @@ def _omnisci_ufunc_not_equal(x1, x2):
 
 
 @binary_expose.implements(np.equal, dtype=typesystem.boolean8)
-def _omnisci_ufunc_equal(x1, x2):
+def _impl_ufunc_equal(x1, x2):
     """
     Computes the truth value of x1_i == x2_i for each element x1_i of the input array x1 with the
     respective element x2_i of the input array x2.
@@ -307,7 +308,7 @@ def _omnisci_ufunc_equal(x1, x2):
 
 
 @binary_expose.implements(np.logical_and, dtype=typesystem.boolean8)
-def _omnisci_ufunc_logical_and(x1, x2):
+def _impl_ufunc_logical_and(x1, x2):
     """
     Computes the logical AND for each element x1_i of the input array x1 with the respective
     element x2_i of the input array x2.
@@ -316,7 +317,7 @@ def _omnisci_ufunc_logical_and(x1, x2):
 
 
 @binary_expose.implements(np.logical_or, dtype=typesystem.boolean8)
-def _omnisci_ufunc_logical_or(x1, x2):
+def _impl_ufunc_logical_or(x1, x2):
     """
     Computes the logical OR for each element x1_i of the input array x1 with the respective
     element x2_i of the input array x2.
@@ -325,7 +326,7 @@ def _omnisci_ufunc_logical_or(x1, x2):
 
 
 @binary_expose.implements(np.logical_xor, dtype=typesystem.boolean8)
-def _omnisci_ufunc_logical_xor(x1, x2):
+def _impl_ufunc_logical_xor(x1, x2):
     """
     "Computes the logical XOR for each element x1_i of the input array x1 with the respective
     element x2_i of the input array x2.
@@ -334,33 +335,33 @@ def _omnisci_ufunc_logical_xor(x1, x2):
 
 
 @binary_expose.implements(np.maximum, api=API.NUMPY_API)
-def _omnisci_ufunc_maximum(x1, x2):
+def _impl_ufunc_maximum(x1, x2):
     pass
 
 
 @binary_expose.implements(np.minimum, api=API.NUMPY_API)
-def _omnisci_ufunc_minimum(x1, x2):
+def _impl_ufunc_minimum(x1, x2):
     pass
 
 
 @binary_expose.implements(np.fmax, api=API.NUMPY_API)
-def _omnisci_ufunc_fmax(x1, x2):
+def _impl_ufunc_fmax(x1, x2):
     pass
 
 
 @binary_expose.implements(np.fmin, api=API.NUMPY_API)
-def _omnisci_ufunc_fmin(x1, x2):
+def _impl_ufunc_fmin(x1, x2):
     pass
 
 
 # Floating functions
 @binary_expose.implements(np.nextafter, api=API.NUMPY_API)
-def _omnisci_ufunc_nextafter(x1, x2):
+def _impl_ufunc_nextafter(x1, x2):
     pass
 
 
 @binary_expose.implements(np.ldexp, api=API.NUMPY_API)
-def _omnisci_ufunc_ldexp(x1, x2):
+def _impl_ufunc_ldexp(x1, x2):
     pass
 
 
@@ -368,7 +369,7 @@ def _omnisci_ufunc_ldexp(x1, x2):
 
 
 @unary_expose.implements(np.around, ufunc_name='round')
-def _omnisci_ufunc_round(a):
+def _impl_ufunc_round(a):
     """
     Rounds each element x_i of the input array x to the nearest integer-valued number.
     """
@@ -376,26 +377,26 @@ def _omnisci_ufunc_round(a):
 
 
 @unary_expose.implements(np.negative)
-def _omnisci_ufunc_negative(a):
+def _impl_ufunc_negative(a):
     """Computes the numerical negative of each element x_i (i.e., y_i = -x_i) of the
     input array x."""
     pass
 
 
 @unary_expose.implements(np.positive)
-def _omnisci_ufunc_positive(a):
+def _impl_ufunc_positive(a):
     """Computes the numerical positive of each element x_i (i.e., y_i = +x_i) of the
     input array x."""
     pass
 
 
 @unary_expose.implements(np.absolute, api=API.NUMPY_API)
-def _omnisci_ufunc_absolute(a):
+def _impl_ufunc_absolute(a):
     pass
 
 
 @unary_expose.implements(np.absolute, ufunc_name='abs')
-def _omnisci_ufunc_abs(a):
+def _impl_ufunc_abs(a):
     """
     Calculates the absolute value for each element x_i of the input array x (i.e., the element-
     wise result has the same magnitude as the respective element in x but has positive sign).
@@ -404,12 +405,12 @@ def _omnisci_ufunc_abs(a):
 
 
 @unary_expose.implements(np.rint, api=API.NUMPY_API)
-def _omnisci_ufunc_rint(a):
+def _impl_ufunc_rint(a):
     pass
 
 
 @unary_expose.implements(np.sign)
-def _omnisci_ufunc_sign(a):
+def _impl_ufunc_sign(a):
     """
     Returns an indication of the sign of a number for each element x_i of the input array x.
     """
@@ -417,17 +418,17 @@ def _omnisci_ufunc_sign(a):
 
 
 @unary_expose.implements(np.conj, ufunc_name='conj', api=API.NUMPY_API)
-def _omnisci_ufunc_conj(a):
+def _impl_ufunc_conj(a):
     pass
 
 
 @unary_expose.implements(np.conjugate, api=API.NUMPY_API)
-def _omnisci_ufunc_conjugate(a):
+def _impl_ufunc_conjugate(a):
     pass
 
 
 @unary_expose.implements(np.exp)
-def _omnisci_ufunc_exp(a):
+def _impl_ufunc_exp(a):
     """Calculates an implementation-dependent approximation to the exponential function, having
     domain.
 
@@ -440,12 +441,12 @@ def _omnisci_ufunc_exp(a):
 
 
 @unary_expose.implements(np.exp2, api=API.NUMPY_API)
-def _omnisci_ufunc_exp2(a):
+def _impl_ufunc_exp2(a):
     pass
 
 
 @unary_expose.implements(np.log)
-def _omnisci_ufunc_log(a):
+def _impl_ufunc_log(a):
     """
     Calculates an implementation-dependent approximation to the natural (base e) logarithm, having
     domain [0, +infinity] and codomain [-infinity, +infinity], for each element x_i of the input
@@ -455,7 +456,7 @@ def _omnisci_ufunc_log(a):
 
 
 @unary_expose.implements(np.log2)
-def _omnisci_ufunc_log2(a):
+def _impl_ufunc_log2(a):
     """Calculates an implementation-dependent approximation to the base 2 logarithm, having
     domain.
 
@@ -469,7 +470,7 @@ def _omnisci_ufunc_log2(a):
 
 
 @unary_expose.implements(np.log10)
-def _omnisci_ufunc_log10(a):
+def _impl_ufunc_log10(a):
     """Calculates an implementation-dependent approximation to the base 10 logarithm, having
     domain.
 
@@ -483,7 +484,7 @@ def _omnisci_ufunc_log10(a):
 
 
 @unary_expose.implements(np.expm1)
-def _omnisci_ufunc_expm1(a):
+def _impl_ufunc_expm1(a):
     """Calculates an implementation-dependent approximation to exp(x)-1, having domain [-infinity,
 
     +infinity] and codomain [-1, +infinity], for each element x_i of the
@@ -494,7 +495,7 @@ def _omnisci_ufunc_expm1(a):
 
 
 @unary_expose.implements(np.log1p)
-def _omnisci_ufunc_log1p(a):
+def _impl_ufunc_log1p(a):
     """
     Calculates an implementation-dependent approximation to log(1+x), where log refers to the
     natural (base e) logarithm, having domain [-1, +infinity] and codomain [-infinity, +infinity],
@@ -504,7 +505,7 @@ def _omnisci_ufunc_log1p(a):
 
 
 @unary_expose.implements(np.sqrt)
-def _omnisci_ufunc_sqrt(a):
+def _impl_ufunc_sqrt(a):
     """
     Calculates the square root, having domain [0, +infinity] and codomain [0, +infinity], for each
     element x_i of the input array x.
@@ -513,30 +514,30 @@ def _omnisci_ufunc_sqrt(a):
 
 
 @unary_expose.implements(np.square)
-def _omnisci_ufunc_square(a):
+def _impl_ufunc_square(a):
     """Squares (x_i * x_i) each element x_i of the input array x."""
     pass
 
 
 # @unary_expose.implements(np.cbrt)  # not supported by numba
 @unary_expose.not_implemented('cbrt')
-def _omnisci_ufunc_cbrt(a):
+def _impl_ufunc_cbrt(a):
     pass
 
 
 @unary_expose.implements(np.reciprocal, api=API.NUMPY_API)
-def _omnisci_ufunc_reciprocal(a):
+def _impl_ufunc_reciprocal(a):
     pass
 
 
 # Bit-twiddling functions
 @unary_expose.implements(np.invert, api=API.NUMPY_API)
-def _omnisci_ufunc_invert(a):
+def _impl_ufunc_invert(a):
     pass
 
 
 @unary_expose.implements(np.invert, ufunc_name='bitwise_invert')
-def _omnisci_ufunc_bitwise_invert(a):
+def _impl_ufunc_bitwise_invert(a):
     """
     Inverts (flips) each bit for each element x_i of the input array x.
     """
@@ -545,7 +546,7 @@ def _omnisci_ufunc_bitwise_invert(a):
 
 # trigonometric functions
 @unary_expose.implements(np.sin)
-def _omnisci_ufunc_sin(a):
+def _impl_ufunc_sin(a):
     """Calculates an implementation-dependent approximation to the sine, having domain (-infinity,
 
     +infinity) and codomain [-1, +1], for each element x_i of the input
@@ -556,7 +557,7 @@ def _omnisci_ufunc_sin(a):
 
 
 @unary_expose.implements(np.cos)
-def _omnisci_ufunc_cos(a):
+def _impl_ufunc_cos(a):
     """Calculates an implementation-dependent approximation to the cosine, having domain
     (-infinity,
 
@@ -568,7 +569,7 @@ def _omnisci_ufunc_cos(a):
 
 
 @unary_expose.implements(np.tan)
-def _omnisci_ufunc_tan(a):
+def _impl_ufunc_tan(a):
     """Calculates an implementation-dependent approximation to the tangent, having domain
     (-infinity,
 
@@ -580,12 +581,12 @@ def _omnisci_ufunc_tan(a):
 
 
 @unary_expose.implements(np.arcsin, api=API.NUMPY_API)
-def _omnisci_ufunc_arcsin(a):
+def _impl_ufunc_arcsin(a):
     pass
 
 
 @unary_expose.implements(np.arcsin, ufunc_name='asin')
-def _omnisci_ufunc_asin(a):
+def _impl_ufunc_asin(a):
     """
     Calculates an implementation-dependent approximation of the principal value of the inverse
     sine, having domain [-1, +1] and codomain [-π/2, +π/2] for each element x_i of the input array
@@ -595,12 +596,12 @@ def _omnisci_ufunc_asin(a):
 
 
 @unary_expose.implements(np.arccos, api=API.NUMPY_API)
-def _omnisci_ufunc_arccos(a):
+def _impl_ufunc_arccos(a):
     pass
 
 
 @unary_expose.implements(np.arccos, ufunc_name='acos')
-def _omnisci_ufunc_acos(a):
+def _impl_ufunc_acos(a):
     """
     Calculates an implementation-dependent approximation of the principal value of the inverse
     cosine, having domain [-1, +1] and codomain [+0, +π], for each element x_i of the input array
@@ -610,12 +611,12 @@ def _omnisci_ufunc_acos(a):
 
 
 @unary_expose.implements(np.arctan, api=API.NUMPY_API)
-def _omnisci_ufunc_arctan(a):
+def _impl_ufunc_arctan(a):
     pass
 
 
 @unary_expose.implements(np.arctan, ufunc_name='atan')
-def _omnisci_ufunc_atan(a):
+def _impl_ufunc_atan(a):
     """
     Calculates an implementation-dependent approximation of the principal value of the inverse
     tangent, having domain [-infinity, +infinity] and codomain [-π/2, +π/2], for each element x_i
@@ -625,7 +626,7 @@ def _omnisci_ufunc_atan(a):
 
 
 @unary_expose.implements(np.sinh)
-def _omnisci_ufunc_sinh(a):
+def _impl_ufunc_sinh(a):
     """Calculates an implementation-dependent approximation to the hyperbolic sine, having domain.
 
     [-infinity, +infinity] and codomain [-infinity, +infinity], for each
@@ -636,7 +637,7 @@ def _omnisci_ufunc_sinh(a):
 
 
 @unary_expose.implements(np.cosh)
-def _omnisci_ufunc_cosh(a):
+def _impl_ufunc_cosh(a):
     """Calculates an implementation-dependent approximation to the hyperbolic cosine, having
     domain.
 
@@ -648,7 +649,7 @@ def _omnisci_ufunc_cosh(a):
 
 
 @unary_expose.implements(np.tanh)
-def _omnisci_ufunc_tanh(a):
+def _impl_ufunc_tanh(a):
     """Calculates an implementation-dependent approximation to the hyperbolic tangent, having
     domain.
 
@@ -660,12 +661,12 @@ def _omnisci_ufunc_tanh(a):
 
 
 @unary_expose.implements(np.arcsinh, api=API.NUMPY_API)
-def _omnisci_ufunc_arcsinh(a):
+def _impl_ufunc_arcsinh(a):
     pass
 
 
 @unary_expose.implements(np.arcsinh, ufunc_name='asinh')
-def _omnisci_ufunc_asinh(a):
+def _impl_ufunc_asinh(a):
     """
     Calculates an implementation-dependent approximation to the inverse hyperbolic sine, having
     domain [-infinity, +infinity] and codomain [-infinity, +infinity], for each element x_i in the
@@ -675,12 +676,12 @@ def _omnisci_ufunc_asinh(a):
 
 
 @unary_expose.implements(np.arccosh, api=API.NUMPY_API)
-def _omnisci_ufunc_arccosh(a):
+def _impl_ufunc_arccosh(a):
     pass
 
 
 @unary_expose.implements(np.arccosh, ufunc_name='acosh')
-def _omnisci_ufunc_acosh(a):
+def _impl_ufunc_acosh(a):
     """
     Calculates an implementation-dependent approximation to the inverse hyperbolic cosine, having
     domain [+1, +infinity] and codomain [+0, +infinity], for each element x_i of the input array
@@ -690,12 +691,12 @@ def _omnisci_ufunc_acosh(a):
 
 
 @unary_expose.implements(np.arctanh, api=API.NUMPY_API)
-def _omnisci_ufunc_arctanh(a):
+def _impl_ufunc_arctanh(a):
     pass
 
 
 @unary_expose.implements(np.arctanh, ufunc_name='atanh')
-def _omnisci_ufunc_atanh(a):
+def _impl_ufunc_atanh(a):
     """
     Calculates an implementation-dependent approximation to the inverse hyperbolic tangent, having
     domain [-1, +1] and codomain [-infinity, +infinity], for each element x_i of the input array
@@ -705,28 +706,28 @@ def _omnisci_ufunc_atanh(a):
 
 
 @unary_expose.implements(np.degrees, api=API.NUMPY_API)
-def _omnisci_ufunc_degrees(a):
+def _impl_ufunc_degrees(a):
     pass
 
 
 @unary_expose.implements(np.radians, api=API.NUMPY_API)
-def _omnisci_ufunc_radians(a):
+def _impl_ufunc_radians(a):
     pass
 
 
 @unary_expose.implements(np.deg2rad, api=API.NUMPY_API)
-def _omnisci_ufunc_deg2rad(a):
+def _impl_ufunc_deg2rad(a):
     pass
 
 
 @unary_expose.implements(np.rad2deg, api=API.NUMPY_API)
-def _omnisci_ufunc_rad2deg(a):
+def _impl_ufunc_rad2deg(a):
     pass
 
 
 # Comparison functions
 @unary_expose.implements(np.logical_not, dtype=typesystem.boolean8)
-def _omnisci_ufunc_logical_not(a):
+def _impl_ufunc_logical_not(a):
     """
     Computes the logical NOT for each element x_i of the input array x.
     """
@@ -735,7 +736,7 @@ def _omnisci_ufunc_logical_not(a):
 
 # Floating functions
 @unary_expose.implements(np.isfinite, dtype=typesystem.boolean8)
-def _omnisci_ufunc_isfinite(a):
+def _impl_ufunc_isfinite(a):
     """
     Tests each element x_i of the input array x to determine if finite (i.e., not NaN and not
     equal to positive or negative infinity).
@@ -744,7 +745,7 @@ def _omnisci_ufunc_isfinite(a):
 
 
 @unary_expose.implements(np.isinf, dtype=typesystem.boolean8)
-def _omnisci_ufunc_isinf(a):
+def _impl_ufunc_isinf(a):
     """
     Tests each element x_i of the input array x to determine if equal to positive or negative
     infinity.
@@ -753,7 +754,7 @@ def _omnisci_ufunc_isinf(a):
 
 
 @unary_expose.implements(np.isnan, dtype=typesystem.boolean8)
-def _omnisci_ufunc_isnan(a):
+def _impl_ufunc_isnan(a):
     """
     Tests each element x_i of the input array x to determine whether the element is NaN.
     """
@@ -761,12 +762,12 @@ def _omnisci_ufunc_isnan(a):
 
 
 @unary_expose.implements(np.fabs, dtype=types.double, api=API.NUMPY_API)
-def _omnisci_ufunc_fabs(a):
+def _impl_ufunc_fabs(a):
     pass
 
 
 @unary_expose.implements(np.floor, dtype=types.double)
-def _omnisci_ufunc_floor(a):
+def _impl_ufunc_floor(a):
     """
     Rounds each element x_i of the input array x to the greatest (i.e., closest to +infinity)
     integer-valued number that is not greater than x_i.
@@ -775,7 +776,7 @@ def _omnisci_ufunc_floor(a):
 
 
 @unary_expose.implements(np.ceil, dtype=types.double)
-def _omnisci_ufunc_ceil(a):
+def _impl_ufunc_ceil(a):
     """
     Rounds each element x_i of the input array x to the smallest (i.e., closest to -infinity)
     integer-valued number that is not less than x_i.
@@ -784,7 +785,7 @@ def _omnisci_ufunc_ceil(a):
 
 
 @unary_expose.implements(np.trunc, dtype=types.double)
-def _omnisci_ufunc_trunc(a):
+def _impl_ufunc_trunc(a):
     """
     Rounds each element x_i of the input array x to the integer-valued number that is closest to
     but no greater than x_i.
@@ -795,18 +796,18 @@ def _omnisci_ufunc_trunc(a):
 # not supported?
 # @unary_expose.implements(np.isnat, dtype=types.int8)
 @unary_expose.not_implemented('isnat')
-def _omnisci_ufunc_isnat(a):
+def _impl_ufunc_isnat(a):
     pass
 
 
 # issue 152:
 @unary_expose.implements(np.signbit, dtype=typesystem.boolean8, api=API.NUMPY_API)
-def _omnisci_ufunc_signbit(a):
+def _impl_ufunc_signbit(a):
     pass
 
 
 @unary_expose.implements(np.spacing, dtype=types.double, api=API.NUMPY_API)
-def _omnisci_ufunc_spacing(a):
+def _impl_ufunc_spacing(a):
     pass
 
 
