@@ -100,6 +100,9 @@ class TargetInfo(object):
         self._supported_libraries = set()  # libfuncs.Library instances
         self._userdefined_externals = set()
 
+    def __repr__(self):
+        return f'{self.__class__.__name__}(name={self.name!r})'
+
     def add_external(self, *names):
         self._userdefined_externals.update(names)
 
@@ -123,7 +126,8 @@ class TargetInfo(object):
         return False
 
     def todict(self):
-        return dict(name=self.name, strict=self.strict, info=self.info,
+        return dict(name=self.name, strict=self.strict,
+                    info=self.info,
                     type_sizeof=self.type_sizeof,
                     libraries=[lib.name for lib in self._supported_libraries],
                     externals=list(self._userdefined_externals))
@@ -142,7 +146,7 @@ class TargetInfo(object):
         if isinstance(data, type(self)):
             data = data.todict()
         self.info.update(data.get('info', {}))
-        self.type_sizeof.update(data.get('typeof_sizeof', {}))
+        self.type_sizeof.update(data.get('type_sizeof', {}))
         for lib in data.get('libraries', []):
             self.add_library(lib)
         self.add_external(*data.get('externals', []))
@@ -213,7 +217,6 @@ class TargetInfo(object):
         target_info.add_library('m')
         target_info.add_library('stdio')
         target_info.add_library('stdlib')
-
         cls._host_target_info_cache[key] = target_info
 
         return target_info
@@ -224,7 +227,7 @@ class TargetInfo(object):
         supported_keys = ('name', 'triple', 'datalayout', 'features', 'bits',
                           'compute_capability', 'count', 'threads', 'cores',
                           'has_cpython', 'has_numba', 'driver', 'software',
-                          'llvm_version', 'null_values')
+                          'llvm_version', 'null_values', 'has_libdevice')
         if prop not in supported_keys:
             print(f'rbc.{type(self).__name__}:'
                   f' unsupported property {prop}={value}.')
@@ -279,8 +282,23 @@ class TargetInfo(object):
         if bits is not None:
             return bits
         # expand this dict as needed
-        return dict(x86_64=64, nvptx64=64,
-                    x86=32, nvptx=32)[self.arch]
+        bits = dict(
+            x86_64=64, nvptx64=64, arm64=64, aarch64=64,
+            x86=32, nvptx=32,
+        ).get(self.arch)
+        if bits is None:
+            if '64' in self.arch:
+                warnings.warn(
+                    f"Unknown {self.arch} architecture: inferring 64 bits."
+                    "Please report this warning."
+                )
+                bits = 64
+            else:
+                raise SystemError(
+                    f"Unknown {self.arch} architecture."
+                    "Please report this error."
+                )
+        return bits
 
     @property
     def datalayout(self):
@@ -333,19 +351,25 @@ class TargetInfo(object):
     def has_numba(self):
         """Check if target supports numba symbols
         """
-        return self.info.get('has_numba', False)
+        return bool(int(self.info.get('has_numba', False)))
 
     @property
     def has_numpy(self):
         """Check if target supports numpy symbols
         """
-        return self.info.get('has_numpy', False)
+        return bool(int(self.info.get('has_numpy', False)))
+
+    @property
+    def has_libdevice(self):
+        """Check if target has libdevice (CUDA math library) available
+        """
+        return bool(int(self.info.get('has_libdevice', False)))
 
     @property
     def has_cpython(self):
         """Check if target supports Python C/API symbols
         """
-        return self.info.get('has_cpython', False)
+        return bool(int(self.info.get('has_cpython', False)))
 
     @property
     def llvm_version(self):
@@ -359,7 +383,7 @@ class TargetInfo(object):
         """
         null_values = self.info.get('null_values', {})
         if not null_values:
-            raise RuntimeError('null value support requires omniscidb-internal PR 5104')
+            raise RuntimeError('null value support requires heavydb-internal PR 5104')
         return null_values
 
     # TODO: info may also contain: count, threads, cores
